@@ -1,6 +1,7 @@
 from .clb import TencentClb, TencentClbListener
 from .cdn import TencentCdnDomain
 from .cfs import TencentCfs
-from .vpc import TencentRouteTable, TencentRouteEntry, TencentSubnet
+from .vpc import TencentRouteTable, TencentRouteEntry, TencentSubnet, TencentEip, TencentSecurityGroup
 from .dns import  TencentDnsDomain, TencentDnsRecord
 from .postgres import TencentPostgreSQL
+from .cbs import TencentCbs
\ No newline at end of file
